##  Overview
The SAP LeanIX Architecture and Road Map Planning complements SAP LeanIX Application Portfolio Management, providing advanced features to assist you in planning and executing transformations within your enterprise architecture. SAP LeanIX Architecture and Road Map Planning is particularly useful for [application modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs.") and [ERP transformation](https://help.sap.com/docs/leanix/ea/erp-transformation?locale=en-US&state=PRODUCTION&version=CLOUD "Step-by-step guide for ERP Transformation using SAP LeanIX.") use cases, allowing you to plan your target architecture and monitor initiative progress efficiently.
In this article, we will explore the key features of SAP LeanIX Architecture and Road Map Planning and its capabilities, and demonstrate how to integrate them into your existing SAP LeanIX workflows seamlessly. For step-by-step instructions on each feature, refer to the user guides available on the corresponding sub-pages.
